/*
 * Copyright 2010 by Kappich Systemberatung Aachen
 *
 * This file is part of de.bsvrz.pua.prot.
 *
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */

package de.bsvrz.pua.prot.data;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.config.AttributeType;
import de.bsvrz.pua.prot.client.dataobject.Column;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Stellt ein Datenobjekt über eine ganze Zeile dar.<br><br>
 *
 * Bietet eine Kapselung der Protokolldaten in ein Interface, wie es Dav-Daten benutzen. Anders als Dav-Daten sind diese Daten nicht streng an die verwendete
 * Attributgruppe bzw. das verwendete Attribut gebunden (sofern überhaupt eines existiert). Je nach Anwendungsfall bieten sich daher auch Abfragen nach {@link
 * #isDefined()}, {@link #isPlain()} usw. an, auch wenn die Attributgruppe diese Daten eigentlich nicht unterstützen würde. Besonders wichtig ist dies bei
 * Fehlermeldungen von PuA (wie z.B. einer Division durch 0, oder einem "Keine Daten"-Datensatz), da hier die Meldung unabhängig vom Attributtyp über
 * {@link #asTextValue()} abgerufen werden kann.
 *
 *
 * @author Kappich Systemberatung
 * @version $Revision: 0000 $
 */
public final class MultiColumnProtocolData extends ProtocolData{

	private final Map<String, Data> _internalData = new HashMap<>();

	private final List<ProtocolData> _list;

	/**
	 * Ersteltl ein neues Data-Objekt, dass über ein ganze Zeile in einem PuA-Ergebnissatz geht
	 * @param list Liste mit Datenobjekten
	 * @param columns zugehörige Spaltenköpfe
	 */
	public MultiColumnProtocolData(final List<ProtocolData> list, final Column[] columns) {
		int i = 0;
		_list = list;
		for(final ProtocolData protocolData : list) {
			String columnName = columns[i++].getColumnName();
			if(columnName == null) columnName = protocolData.getName();
			_internalData.put(columnName, protocolData);
		}
	}

	@Override
	public boolean isError() {
		return false;
	}

	@Override
	protected List<Data> getChildrenList() {
		return new ArrayList<>(_list);
	}

	public Data createUnmodifiableCopy() {
		throw new UnsupportedOperationException("Kopie der Daten ist bei kompletten Zeilen nicht möglich.");
	}

	public String getName() {
		return "";
	}

	public AttributeType getAttributeType() {
		return null;
	}

	public boolean isDefined() {
		return true;
	}

	@Override
	public boolean isNoChange() {
		return false;
	}

	public boolean isList() {
		return true;
	}

	public boolean isArray() {
		return false;
	}

	public boolean isPlain() {
		return false;
	}

	public Data getItem(final String itemName) {
		return _internalData.get(itemName);
	}

	public TextValue asTextValue() {
		throw new UnsupportedOperationException(ProtocolData.MESSAGE_NOT_ATOMAR);
	}

	public TimeValue asTimeValue() {
		throw new UnsupportedOperationException(ProtocolData.MESSAGE_NOT_ATOMAR);
	}

	public NumberValue asScaledValue() {
		throw new UnsupportedOperationException(ProtocolData.MESSAGE_NOT_ATOMAR);
	}

	public NumberValue asUnscaledValue() {
		throw new UnsupportedOperationException(ProtocolData.MESSAGE_NOT_ATOMAR);
	}

	public ReferenceValue asReferenceValue() {
		throw new UnsupportedOperationException(ProtocolData.MESSAGE_NOT_ATOMAR);
	}

	public Array asArray() {
		throw new UnsupportedOperationException(ProtocolData.MESSAGE_NOT_ARRAY);
	}

	public TextArray asTextArray() {
		throw new UnsupportedOperationException(ProtocolData.MESSAGE_NOT_ARRAY);
	}

	public TimeArray asTimeArray() {
		throw new UnsupportedOperationException(ProtocolData.MESSAGE_NOT_ARRAY);
	}

	public NumberArray asScaledArray() {
		throw new UnsupportedOperationException(ProtocolData.MESSAGE_NOT_ARRAY);
	}

	public NumberArray asUnscaledArray() {
		throw new UnsupportedOperationException(ProtocolData.MESSAGE_NOT_ARRAY);
	}

	public ReferenceArray asReferenceArray() {
		throw new UnsupportedOperationException(ProtocolData.MESSAGE_NOT_ARRAY);
	}
}
