/*
 * Copyright 2005-2008 by beck et al. projects GmbH, Munich
 * Copyright 2009 by Kappich Systemberatung, Aachen
 *
 * This file is part of de.bsvrz.pua.prot.
 *
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */

package de.bsvrz.pua.prot.aggregations;

import de.bsvrz.pua.prot.util.ArithmeticOperation;
import de.bsvrz.pua.prot.util.ExpressionResult;
import de.bsvrz.pua.prot.util.ExpressionResult.ResultType;
import de.bsvrz.pua.prot.util.ResultValue;
import de.bsvrz.sys.funclib.debug.Debug;
import de.bsvrz.sys.funclib.losb.messages.ErrorMessage;

import java.io.Serializable;
import java.util.function.Supplier;

/**
 * Minimum Aggregation. <br>Die Klasse implementiert {@link java.io.Serializable} nur, da dies für bestimmte Tests erforderlich ist.
 *
 * @author beck et al. projects GmbH
 * @author Martin Hilgers
 * @version $Revision$ / $Date$ / ($Author$)
 */
public class Minimum extends AbstractAggregation<AggregationResultValue> {

	@Override
	protected Supplier<AggregationResultValue> createAggregationResultValue() {
		return AggregationResultValue::new;
	}

	@Override
	public void aggregate(final AggregationResultValue result, final ExpressionResult newValue) {
		try {
			if(new ArithmeticOperation(result.getValue(), newValue).greater()) {
				result.set(newValue);
			}
		}
		catch(IllegalArgumentException e) {
			// Ungültige Parameter
			result.set(ExpressionResult.error(e.getMessage()));
		}
	}

	@Override
	public void finish(final AggregationResultValue finalResult) {
		if(!finalResult.getValue().isArithmetic()){
			finalResult.set(new ExpressionResult());
		}
	}

	/** @see de.bsvrz.pua.prot.aggregations.Aggregation#getAggregationName() */
	public String getAggregationName() {
		return "Minimum";
	}
}
