/*
 * Copyright 2005-2008 by beck et al. projects GmbH, Munich
 * Copyright 2009 by Kappich Systemberatung, Aachen
 *
 * This file is part of de.bsvrz.pua.prot.
 *
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */

package de.bsvrz.pua.prot.processing;

import de.bsvrz.pua.prot.util.JobState;

/**
 * Schnittstelle zur Datenaufbereitung. Die Datenaufbereitung stellt Methoden zum<br> - Protokollerstellung<br> - Abbrechen der Protokollerstellung<br> -
 * Statusanfrage zur Verfügung.
 *
 * @author beck et al. projects GmbH
 * @author Martin Hilgers
 * @version $Revision$ / $Date$ / ($Author$)
 */
public interface ProcessingInterface {

	/**
	 * Startet die Datenaufbereitung.
	 *
	 * @param abort Zeigt an ob die Datenaufbereitung abgebrochen werden soll.In diesem Fall wird eine negative Quittung an den Auftraggeber gesandt.
	 *              Administrations- und Aggregations- Datensatz werden immer an den Auftraggeber gesendet.
	 *
	 */
	public void process(boolean abort);

	/** Bricht die Datenaufbereitung ab. */
	public void abort();

	/**
	 * Anfrage nach dem Status der Datenaufbereitung
	 *
	 * @return Statusinformation
	 */
	public byte getStatus();

	/** Versand von Protokolldatensätzen anhalten. */
	public void pauseProcessing();

	/** Versand von Protokolldatensätzen fortsetzen. */
	public void resumeProcessing();

	/**
	 * Zum Abfragen der Protokoll-Id.
	 *
	 * @return Liefert die Protokoll-Id des Protokolls.
	 */
	public long getProtocolId();

	/**
	 * Gibt die Auftrags-Id zurück
	 * @return Id des Auftrags
	 */
	public long getJobId();

	/**
	 * Gibt den Status des Auftrags zurück
	 * @return Status
	 */
	JobState getJobState();

	/**
	 * Clientseitige automatische flusskontrolle. Der Client gibt vor, bis zu welchem Datensatz PuA Datensätze mit voller
	 * Geschwindigkeit senden soll. danach wird der Versand stark ausgebremst (nicht völlig gestoppt, da PuA sonst evtl. nicht merkt,
	 * ob der Client noch erreichbar ist)
	 * @param numData Bis zu welcher Datensatznummer (einfach durchnummeriert) Daten gesendet werden sollen.
	 */
	void flowControl(long numData);

	/**
	 * Bricht die Übertragung des Protokolls ab. Im Gegensatz zu abort wird das Protokoll trotzdem noch zuende berechnet und gespeichert
	 * (wenn es sich um einen entsprechenden Auftrag handelt)
	 */
	void stopProtocolTransmission();
}
