/*
 * Copyright 2005-2008 by beck et al. projects GmbH, Munich
 * Copyright 2009 by Kappich Systemberatung, Aachen
 *
 * This file is part of de.bsvrz.pua.prot.
 *
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */

package de.bsvrz.pua.prot.processing.onlinebuffer;

/**
 * Klasse zum Abfragen von Online-Daten.<br> Objekte dieser Klasse dürfen nicht zum synchronisieren verwendet werden. D.h. <code>notify</code> und
 * <code>notifyAll()</code> düfen nicht verwendet werden! (Diese Methoden können nicht überschrieben werden, da sie als <code>final</code> deklariert wurden.)
 *
 * @author beck et al. projects GmbH
 * @author Martin Hilgers
 * @version $Revision$ / $Date$ / ($Author$)
 */
@SuppressWarnings("deprecation")
public class OnlineDataReceiver {

	/** Objekt das die Datensammlung durchführt. */
	private OnlineDataReceiverObject _receiver;

	protected OnlineDataReceiver(OnlineDataReceiverObject receiver) {
		this._receiver = receiver;
	}

	/**
	 * Liefert einen Datensatz. Die Methode wartet bis ein Datensatz eingetroffen ist.
	 *
	 * @param timeout Maximale Wartezeit. Wird die Wartezeit überschritten, so wird die Methode abgebrochen und <code>false</code> zurückgegeben. Ist dieser
	 *                Parameter <code>0</code> so wird solange gewartet, bis Daten eintreffen.
	 *
	 * @return Empfangener Datensatz.
	 *
	 * @throws InterruptedException Warten auf Antwortdatensatz wurde unterbrochen.
	 */
	public ExtResultData take(long timeout) throws InterruptedException {
		if(_receiver != null) {
			return _receiver.take(timeout, this);
		}
		else {
			return null;
		}
	}

	/** Meldet den Empfang von Daten ab. Das Objekt meldet sich vom Empfang der Daten ab. */
	public void unsubscribe() {
		if(_receiver != null) {
			_receiver.unsubscribe(this);
		}
		else {
			_receiver = null;
		}
	}
}


