/*
 * Copyright 2005-2008 by beck et al. projects GmbH, Munich
 * Copyright 2009 by Kappich Systemberatung, Aachen
 *
 * This file is part of de.bsvrz.pua.prot.
 *
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */

package de.bsvrz.pua.prot.util.attributes;

import de.bsvrz.pua.prot.aggregations.Aggregation;
import de.bsvrz.pua.prot.util.Qualifier;
import de.bsvrz.sys.funclib.losb.util.Util;

import java.util.*;


/**
 * Basisklasse aller Attributrepräsentationen. Es existieren drei verschiedene Repräsentationen: 1. Reale Attribute, werden durch RealAttributeDescription
 * modelliert 2. temporäre Attribute: Werden durch TempAttributeDescription modelliert 3. Zeitdauer: Wird durch Elements modelliert
 *
 * @author beck et al. projects GmbH
 * @author Martin Hilgers
 * @version $Revision$ / $Date$ / ($Author$)
 */
public abstract class Elements {

	private String _columnName = null;

	private List<Class<? extends Aggregation>> _aggregationClasses = new ArrayList<>();

	/** Konstruktor */
	public Elements() {
	}

	/**
	 * Konstruktor zu Testzwecken.
	 *
	 * @param columnName  Name. Kann <code>null</code> sein.
	 * @param aggregationList Zu verwendende Aggregation. Kann <code>null</code> sein.
	 */
	public Elements(String columnName, List<Class<? extends Aggregation>> aggregationList) {
		this._columnName = columnName;
		if(aggregationList != null)	this._aggregationClasses = aggregationList;
	}

	/**
	 * Setzt die zu verwendende Aggregationsfunktion.
	 *
	 * @param aggregation Objekt dass die Aggregation durchführt
	 */
	public void addAggregation(Class<? extends Aggregation> aggregation) {
		this._aggregationClasses.add(aggregation);
	}


	/** @return Gibt HashSet zurück, dass die Datenindices der verwendeten Attribute enthält. */
	public abstract Collection<Qualifier> getQualifiers();


	/**
	 * Liefert die Menge aller von realen Elemente, die von diesem Element verwendet werden.
	 *
	 * @return Menge der realen Elemente.
	 */
	public abstract Set<? extends RealElement> getRealElements();

	public List<Class<? extends Aggregation>> getAggregationClasses() {
		return Collections.unmodifiableList(_aggregationClasses);
	}

	/**
	 * Sollte nicht verwendet werden.
	 * @param aggregationClasses Liste
	 */
	public void setAggregationClasses(final List<Class<? extends Aggregation>> aggregationClasses) {
		
		if(aggregationClasses == null) {
			this._aggregationClasses = new ArrayList<>();
			return;
		}
		this._aggregationClasses = new ArrayList<>(aggregationClasses);
	}

	/** Name der Spalte. Wird durch das Schlüsselwort 'als' im Skript bestimmt. Anfangs <code>null</code>.
	 * @return ColumnName
	  */
	public String getColumnName() {
		return _columnName;
	}

	public void setColumnName(final String columnName) {
		this._columnName = columnName;
	}
}
